<?php

/**
 * bodyfit functions and definitions
  @package bodyfit
 *
*/

/* Set the content width in pixels, based on the theme's design and stylesheet.
*/
function bodyfit_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'bodyfit_content_width', 980 );
}
add_action( 'after_setup_theme', 'bodyfit_content_width', 0 );


if( ! function_exists( 'bodyfit_theme_setup' ) ) {	
	
	function bodyfit_theme_setup() {
		load_theme_textdomain( 'bodyfit', get_template_directory() . '/languages' );
		
		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );
		
		// Add title tag 
		add_theme_support( 'title-tag' );
		
		// Add default logo support		
        add_theme_support( 'custom-logo');

        add_theme_support('post-thumbnails');
        add_image_size('bodyfit-page-thumbnail',738,423, true);
        add_image_size('bodyfit-about-thumbnail',800,550, true);
        add_image_size('bodyfit-blog-front-thumbnail',370,225, true);
        add_image_size('bodyfit-portfolio-thumbnail',900,810, true);
        add_image_size('bodyfit-slider-thumbnail',1350,600, true);
        
        
		
         // Add theme support for Semantic Markup
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption'
		) ); 

		$defaults = array(
			'default-image'          => get_template_directory_uri() .'/scripts/images/header.jpg',
			'width'                  => 1920,
			'height'                 => 600,
			'uploads'                => true,
			'default-text-color'     => "515151",
			
		);
		add_theme_support( 'custom-header', $defaults );

		// Menus
		register_nav_menus(array(
			'primary' => esc_html__('Primary Menu', 'bodyfit'),
		));
		// add excerpt support for pages
        add_post_type_support( 'page', 'excerpt' );
		
        if ( is_singular() && comments_open() ) {
			wp_enqueue_script( 'comment-reply' );
        }
		// Add theme support for selective refresh for widgets.
        add_theme_support( 'customize-selective-refresh-widgets' );
		
		// Custom Backgrounds
   		add_theme_support( 'custom-background', array(
  			'default-color' => 'ffffff',
    	) );

    	// To use additional css
 	    add_editor_style( 'scripts/css/editor-style.css' );
	}
	add_action( 'after_setup_theme', 'bodyfit_theme_setup' );
}

function bodyfit_header_style()
{
	$bodyfit_header_text_color = get_header_textcolor();
	?>
		<style type="text/css">
			<?php
				//Check if user has defined any header image.
				if ( get_header_image() ) :
			?>
				.site-title{
					color: #<?php echo esc_attr($bodyfit_header_text_color); ?>;
					
				}
			<?php endif; ?>	
		</style>
	<?php

}
 

   // Register Nav Walker class_alias
    require get_template_directory(). '/class-wp-bootstrap-navwalker.php';
    require get_template_directory(). '/insert/extras.php';
   /**

    * Enqueue CSS stylesheets
    */		
if( ! function_exists( 'bodyfit_enqueue_styles' ) ) {
	function bodyfit_enqueue_styles() {	
	
	    wp_enqueue_style('bodyfit-font', 'https://fonts.googleapis.com/css?family=Montserrat:400,500,600,700,800|Open+Sans:300,400','');

		
		wp_enqueue_style('font-awesome', get_template_directory_uri() .'/scripts/css/font-awesome.css','');
		wp_enqueue_style('bootstrap', get_template_directory_uri() . '/scripts/css/bootstrap.css','');
		wp_enqueue_style('fancybox', get_template_directory_uri() . '/scripts/css/jquery.fancybox.css','');

	// main style
		wp_enqueue_style( 'bodyfit-style', get_stylesheet_uri() );
		
	}
	add_action( 'wp_enqueue_scripts', 'bodyfit_enqueue_styles' );
}

/**
 * Enqueue JS scripts
 */

if( ! function_exists( 'bodyfit_enqueue_scripts' ) ) {
	function bodyfit_enqueue_scripts() {   
		wp_enqueue_script('jquery');
		wp_enqueue_script('idangerous.swiper', get_template_directory_uri() . '/scripts/js/idangerous.swiper.js',array(),'', true);
		wp_enqueue_script('fancybox', get_template_directory_uri() . '/scripts/js/jquery.fancybox.js',array(),'', true);
		wp_enqueue_script('main-js', get_template_directory_uri() . '/scripts/js/main.js',array(),'', true);
		
	}
	add_action( 'wp_enqueue_scripts', 'bodyfit_enqueue_scripts' );
}

 

     /**
     * Register sidebars for bodyfit
     */

function bodyfit_sidebars() {

	// Blog Sidebar

	register_sidebar(array(
		'name' => esc_html__( 'Blog Sidebar', "bodyfit"),
		'id' => 'blog-sidebar',
		'description' => esc_html__( 'Sidebar on the blog layout.', "bodyfit"),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="middle-title">',
		'after_title' => '</h3>',
	));
  	

	// Footer Sidebar

	register_sidebar(array(
		'name' => esc_html__( 'Footer Widget Area 1', "bodyfit"),
		'id' => 'bodyfit-footer-widget-area-1',
		'description' => esc_html__( 'The footer widget area 1', "bodyfit"),
		'before_widget' => ' <div class="footer-widgets %2$s">',
		'after_widget' => '</div> ',
		'before_title' => '<h3>',
		'after_title' => '</h3>',
	));	
	

	register_sidebar(array(
		'name' => esc_html__( 'Footer Widget Area 2', "bodyfit"),
		'id' => 'bodyfit-footer-widget-area-2',
		'description' => esc_html__( 'The footer widget area 2', "bodyfit"),
		'before_widget' => '<div class="footer-widgets %2$s"> ',
		'after_widget' => ' </div>',
		'before_title' => '<h3>',
		'after_title' => '</h3>',
	));	
	
	register_sidebar(array(
		'name' => esc_html__( 'Footer Widget Area 3', "bodyfit"),
		'id' => 'bodyfit-footer-widget-area-3',
		'description' => esc_html__( 'The footer widget area 3', "bodyfit"),
		'before_widget' => '<div class="footer-widgets %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3>',
		'after_title' => '</h3>',
	));	
	
	register_sidebar(array(
		'name' => esc_html__( 'Footer Widget Area 4', "bodyfit"),
		'id' => 'bodyfit-footer-widget-area-4',
		'description' => esc_html__( 'The footer widget area 4', "bodyfit"),
		'before_widget' => '<div class="footer-widgets %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3>',
		'after_title' => '</h3>',
	));		
}

add_action( 'widgets_init', 'bodyfit_sidebars' );
/**
 * Comment layout
 */
function bodyfit_comments( $comment, $args, $depth ) { ?>
	<div <?php comment_class('comments'); ?> id="<?php comment_ID() ?>">
		<?php if ($comment->comment_approved == '0') : ?>
			<div class="alert alert-info">
			  <p><?php esc_html_e( 'Your comment is awaiting moderation.', 'bodyfit' ) ?></p>
			</div>
		<?php endif; ?>
		
		<div class="commentt">
			    <?php echo get_avatar( $comment,'88', null,'User', array( 'class' => array( 'media-object','' ) )); ?>
			
			    <h4 class="user-name">
				   <?php 
						/* translators: '%1$s %2$s: edit term */
				    printf(esc_html__( '%1$s %2$s', 'bodyfit' ), get_comment_author_link(), edit_comment_link(esc_html__( '(Edit)', 'bodyfit' ),'  ','') )
				    ?>
			     </h4>
			    <div class="comment-info"><?php echo esc_html__( 'Posted at ', 'bodyfit' ); ?><?php echo get_the_date(); ?>
			    	<?php comment_reply_link (array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
			    </div> 
			    <?php comment_text() ;?>
		</div>
	</div>
<?php
} 
 
/**
 * Customizer additions.
 */
  require get_template_directory(). '/insert/customizer.php';
